==> trip-0.1.0.tar.gz: trip-0.1.0/tripstack/lsserver/lsserver.cxx <==
#include <stdio.h>
#include <stdlib.h>
#include <iostream.h>
#include <signal.h>
#ifdef __linux__
    #include <getopt.h>
#endif
#include "LSLocator.hxx"
#include "LSSessionManager.hxx"
#include "cpLog.h"


void
sigAlrm(int signo)
{
    //TODO
}


int
main(int argc, char** argv)
{
    try
    {
        int c;
        bool errFlg = false, capFlg = false, done = false;
        string logLevel, cap;

        signal(SIGALRM, sigAlrm);

        while(!done)
        {
            c = getopt(argc, argv,"v:c:");
            switch(c)
            {
                case 'v':
                    cerr << "Setting level:" << optarg << endl;
                    cpLogSetPriority(cpLogStrToPriority(optarg));
                break;
                case 'c':
                    capFlg = true;
                    cap = optarg;
                break;
                case '?':
                    errFlg = true;
                    break;
                break; 
                default:
                    done = true;
                break;
            }
            if(errFlg)
            {
                cerr << "Usage :" << argv[0] << "-v LOG_LEVEL  -c send|receive|sendRec" << endl;
                exit(-1);
            }
        }

        TRIPTransMode tMode = TRIP_TRANS_SND_RCV;
        string mode = "Send/Receive mode.";
        if(capFlg)
        {
            if(cap == string("send"))
            {
                tMode = TRIP_TRANS_SND;
                mode = "Send mode.";
            }
            else if(cap == string("receive"))
            {
                tMode = TRIP_TRANS_RCV;
                mode = "Receive mode.";
            }
        }
        cpLog(LOG_INFO, "Starting LS in %s", mode.c_str());
        LSSessionManager& manager = LSSessionManager::instance(1234, tMode);
        manager.run();
    }
    catch(VException& e)
    {
        cerr << "Caught exception:" << e.getDescription().c_str() << endl;
    }
}

==> trip-1.0.0.tar.gz: trip-1.0.0/tripstack/lsserver/lsserver.cxx <==
#include <stdio.h>
#include <stdlib.h>
#include <iostream.h>
#ifdef __linux__
    #include <getopt.h>
#endif
#include "LSLocator.hxx"
#include "LSSessionManager.hxx"
#include "cpLog.h"
int
main(int argc, char** argv)
{
    try
    {
        int c;
        bool errFlg = false, capFlg = false, itadFlg = false, done = false;
        string logLevel, cap;
        int itad;
        while(!done)
        {
            c = getopt(argc, argv,"v:c:i:");
            switch(c)
            {
                case 'v':
                    cerr << "Setting level:" << optarg << endl;
                    cpLogSetPriority(cpLogStrToPriority(optarg));
                break;
                case 'c':
                    capFlg = true;
                    cap = optarg;
                break;
                case 'i':
                    itadFlg = true;
                    itad = atoi(optarg);
                break;
                case '?':
                    errFlg = true;
                    break;
                break; 
                default:
                    done = true;
                break;
            }
        }
        if(errFlg || (!itadFlg))
        {
            cerr << "Usage :" << argv[0] << "[-v LOG_LEVEL]  [-c send|receive|sendRec] -i <itadNumber> " << endl;
            exit(-1);
        }

        TRIPTransMode tMode = TRIP_TRANS_SND_RCV;
        string mode = "Send/Receive mode.";
        if(capFlg)
        {
            if(cap == string("send"))
            {
                tMode = TRIP_TRANS_SND;
                mode = "Send mode.";
            }
            else if(cap == string("receive"))
            {
                tMode = TRIP_TRANS_RCV;
                mode = "Receive mode.";
            }
        }
        cpLog(LOG_INFO, "Starting LS in %s", mode.c_str());
        LSSessionManager& manager = LSSessionManager::instance(itad, tMode);
        manager.run();
    }
    catch(VException& e)
    {
        cerr << "Caught exception:" << e.getDescription().c_str() << endl;
    }
}
